@@ -17,9 +17,9 @@
 **
 ****************************************************************************/
 
-#include <QtGui>
 #include "fastsms.h"
-#include <QInputContext>
+#include <QApplication>
+#include <QDebug>
 
 int main(int argc, char *argv[])
 {
