@@ -1,5 +1,32 @@
+/****************************************************************************
+**
+** Copyright (C) 2010  Aimone Davide realsportcars@hotmail.com
+**
+** This program is free software: you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation, either version 3 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program.  If not, see <http://www.gnu.org/licenses/>.
+**
+****************************************************************************/
+
 #include "textprocessor.h"
 #include "ui_textprocessor.h"
+#include "settingsmenu.h"
+#include "keyboard.h"
+#include <QTimer>
+#include <QSettings>
+#include <QDebug>
+#if defined(Q_WS_MAEMO_5)
+#include <QAbstractKineticScroller>
+#endif
 
 #define STATE_SPACE 0
 #define STATE_SYM 1
@@ -94,7 +121,7 @@ void TextProcessor::processInput(QString sInput,Core::Keyboards sKeyboard)
         bFocusPhoneNumber = true;
 
     if(!bFocusPhoneNumber)
-    {
+    {            
         m_smsEdit->setFocus();
         if(sKeyboard == Core::Qwerty)
             processQwerty(sInput);
@@ -155,8 +182,9 @@ void TextProcessor::sendSms()
         {
             connect(m_smsEdit,SIGNAL(textChanged()),this,SLOT(smsChanged()));
             connect(m_smsEdit,SIGNAL(selectionChanged()),this,SLOT(cursorPosChanged()));
+            //Reset FastWrite status
+            processAlfanumeric(Keyboard::DELETE);
         }
-
     }
 }
 
@@ -698,3 +726,4 @@ void TextProcessor::alarmNewChar()
 {
     m_bTimerNewChar = true;
 }
+
